Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseCgroupFile ¶
ParseCgroupFile parse cgroup file
func RunningInDockerContainer ¶
func RunningInDockerContainer() bool
RunningInDockerContainer determine if it is running in the Container environment. Simply determine by the ways: 1: .dockerenv; 2: cgroups(normal pid=1 in docker)
func RunningInDockerContainerPid ¶
RunningInDockerContainerPid determine if the process with pid is running in the Container environment. Simply determine by the ways: 1: .dockerenv; 2: cgroups(normal pid=1 in docker)
Types ¶
type CpuInfoData ¶
CpuInfoData cpu info data
func CpuInfo ¶
func CpuInfo(container bool, pid int32) CpuInfoData
CpuInfo read the cpu info for Container or not, with the special pid
Click to show internal directories.
Click to hide internal directories.